==> com_clubmanagement_1.1.zip: site/clubmanagement.php <==
<?php
// kein direkter Zugriff
defined('_JEXEC') or die('Restricted access');

require_once( JPATH_ADMINISTRATOR .DS. 'components' .DS. 'com_clubmanagement' .DS. 'helpers' . DS . 'clubmanagement.php' );
require_once( JPATH_ADMINISTRATOR .DS. 'components' .DS. 'com_clubmanagement' .DS. 'helpers' . DS . 'legend.php' );

$params = &JComponentHelper::getParams( 'com_clubmanagement' );
if ($params->get('use_internal_css')) {
	JFactory::getDocument()->addStyleSheet(JURI::root()."administrator/components/com_clubmanagement/assets/default.css");
}

JFactory::getDocument()->addStyleSheet(JURI::root()."administrator/components/com_clubmanagement/assets/jquery-ui.css");
JFactory::getDocument()->addScript(JURI::root()."administrator/components/com_clubmanagement/assets/jquery-1.4.2.min.js");
JFactory::getDocument()->addScriptDeclaration("jQuery.noConflict();");
JFactory::getDocument()->addScript(JURI::root()."administrator/components/com_clubmanagement/assets/jquery-ui.min.js");
JFactory::getDocument()->addScript(JURI::root()."administrator/components/com_clubmanagement/assets/jquery.ui.datepicker-de.js");

JFactory::getDocument()->addScript(JURI::root()."administrator/components/com_clubmanagement/3rdparty/dataTables-1.7/media/js/jquery.dataTables.js");
JFactory::getDocument()->addScript(JURI::root()."administrator/components/com_clubmanagement/3rdparty/dataTables-1.7/media/js/jquery.dataTables.plugin.datesortgerman.js");
JFactory::getDocument()->addStyleSheet(JURI::root()."administrator/components/com_clubmanagement/3rdparty/dataTables-1.7/media/css/demo_table.css");
//JFactory::getDocument()->addStyleSheet(JURI::root()."administrator/components/com_clubmanagement/3rdparty/dataTables-1.7/media/css/demo_page.css");


// laden des Joomla! Basis Controllers
require_once (JPATH_COMPONENT.DS.'controller.php');
// laden von weiterer Controllern
if($controller = JRequest::getWord('controller')) {
	$path = JPATH_COMPONENT.DS.'controllers'.DS.$controller.'.php';
	if (file_exists($path)) {
		require_once $path;
	} else {
		$controller = '';
	}
}
// Erzeugen eines Objekts der Klasse controller
$classname	= 'ClubmanagementController'.ucfirst($controller);
$controller = new $classname( );
// den request task ausleben
$controller->execute(JRequest::getCmd('task'));

// Redirect aus dem controller
$controller->redirect();
?>

==> com_clubmanagement_1.3.zip: site/clubmanagement.php <==
<?php
// kein direkter Zugriff
defined('_JEXEC') or die('Restricted access');

//jimport('joomla.application.component.model');
//JModel::addIncludePath(JPATH_COMPONENT_ADMINISTRATOR.DS.'models');

require_once( JPATH_ADMINISTRATOR .DS. 'components' .DS. 'com_clubmanagement' .DS. 'helpers' . DS . 'clubmanagement.php' );
require_once( JPATH_ADMINISTRATOR .DS. 'components' .DS. 'com_clubmanagement' .DS. 'helpers' . DS . 'legend.php' );
require_once( JPATH_ADMINISTRATOR .DS. 'components' .DS. 'com_clubmanagement' .DS. 'models' . DS . 'teams.php' );
require_once( JPATH_ADMINISTRATOR .DS. 'components' .DS. 'com_clubmanagement' .DS. 'models' . DS . 'teammember.php' );

$params = JComponentHelper::getParams( 'com_clubmanagement' );
if ($params->get('use_internal_css')) {
	JFactory::getDocument()->addStyleSheet(JURI::root()."administrator/components/com_clubmanagement/assets/default.css");
}
//JTable::addIncludePath(JPATH_COMPONENT_ADMINISTRATOR.DS.'tables');
//echo JPATH_COMPONENT_ADMINISTRATOR;
JFactory::getDocument()->addStyleSheet(JURI::root()."administrator/components/com_clubmanagement/assets/jquery-ui.css");
JFactory::getDocument()->addScript(JURI::root()."administrator/components/com_clubmanagement/assets/jquery-1.4.2.min.js");
JFactory::getDocument()->addScriptDeclaration("jQuery.noConflict();");
JFactory::getDocument()->addScript(JURI::root()."administrator/components/com_clubmanagement/assets/jquery-ui.min.js");
JFactory::getDocument()->addScript(JURI::root()."administrator/components/com_clubmanagement/assets/jquery.ui.datepicker-de.js");

JFactory::getDocument()->addScript(JURI::root()."administrator/components/com_clubmanagement/3rdparty/dataTables-1.7/media/js/jquery.dataTables.js");
JFactory::getDocument()->addScript(JURI::root()."administrator/components/com_clubmanagement/3rdparty/dataTables-1.7/media/js/jquery.dataTables.plugin.datesortgerman.js");
JFactory::getDocument()->addStyleSheet(JURI::root()."administrator/components/com_clubmanagement/3rdparty/dataTables-1.7/media/css/demo_table.css");
//JFactory::getDocument()->addStyleSheet(JURI::root()."administrator/components/com_clubmanagement/3rdparty/dataTables-1.7/media/css/demo_page.css");


// laden des Joomla! Basis Controllers
require_once (JPATH_COMPONENT.DS.'controller.php');
// laden von weiterer Controllern
if($controller = JRequest::getWord('controller')) {
	$path = JPATH_COMPONENT.DS.'controllers'.DS.$controller.'.php';
	if (file_exists($path)) {
		require_once $path;
	} else {
		$controller = '';
	}
}
// Erzeugen eines Objekts der Klasse controller
$classname	= 'ClubmanagementController'.ucfirst($controller);
$controller = new $classname( );
// den request task ausleben
$controller->execute(JRequest::getCmd('task'));

// Redirect aus dem controller
$controller->redirect();
?>
